@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "peermanager.h"
 
 #include <QDateTime>
@@ -423,7 +409,7 @@ void PeerManager::setSuperSeeding(bool on, const BitSet &chunks)
     if ((d->superseeder && on) || (!d->superseeder && !on))
         return;
 
-    d->superseeder.reset(on ? new SuperSeeder(d->cnt.getNumChunks()) : 0);
+    d->superseeder.reset(on ? new SuperSeeder(d->cnt.getNumChunks()) : nullptr);
 
     // When entering or exiting superseeding mode kill all peers
     // but first add the current list to the potential_peers list, so we can reconnect later.
@@ -555,7 +541,7 @@ PeerManager::Private::Private(PeerManager *p, Torrent &tor)
     wanted_chunks.setAll(true);
     wanted_changed = false;
     pex_on = !tor.isPrivate();
-    piece_handler = 0;
+    piece_handler = nullptr;
     paused = false;
 }
 
@@ -693,3 +679,5 @@ void PeerManager::Private::connectToPeers()
 }
 
 }
+
+#include "moc_peermanager.cpp"
